@@ -2,19 +2,25 @@
 import csv
 import json
 from os import path
+import os
+import sys
 from jsonschema import validate
 import pandas as pd
-import ndex2
+#import ndex2
+#sys.path.append(os.path.abspath('/Users/aarongary/Development/Projects/ndex2_performance/ndex2-client'))
+from ndex2cx.NiceCXBuilder import NiceCXBuilder #.NiceCXBuilder import NiceCXBuilder
+#from ndex2. import NiceCXNetworkBuilder
 import time
 import re
 import numpy as np
 import types
 import six
 import gspread
-from ndex2.cx.aspects import ATTRIBUTE_DATA_TYPE
 
 version="0.1"
 
+current_directory = path.dirname(path.abspath(__file__))
+
 #=====================
 # NON-CLASS FUNCTIONS
 #=====================
@@ -30,25 +36,25 @@ def convert_pandas_to_nice_cx_with_load_plan(pandas_dataframe, load_plan, max_ro
     validate(load_plan, plan_schema)
 
     node_lookup = {}
-    nice_cx = ndex2.NiceCXNetwork()
+    nice_cx_builder = NiceCXBuilder()
     row_count = 0
     t1 = int(time.time()*1000)
     #Add context if they are defined
     if load_plan.get('context'):
-        nice_cx.set_context([load_plan.get('context')])
+        nice_cx_builder.set_context(load_plan.get('context'))
         #self.ng_builder.addNamespaces(self.plan.context)
 
     total_row_count = pandas_dataframe.shape
     if len(total_row_count) > 1:
-        total_row_count = str(total_row_count[1])
+        total_row_count = str(total_row_count[0])
     for index, row in pandas_dataframe.iterrows():
         # As each row is processed, self.G_nx is updated
-        process_row(nice_cx, load_plan, row, node_lookup)
+        process_row(nice_cx_builder, load_plan, row, node_lookup)
         row_count = row_count + 1
         if max_rows and row_count > max_rows + 2:
             break
 
-        if row_count % 20 == 0:
+        if row_count % 100 == 0:
             print('processing %s out of %s edges' % (str(row_count), total_row_count))
 
         #try :
@@ -94,17 +100,17 @@ def convert_pandas_to_nice_cx_with_load_plan(pandas_dataframe, load_plan, max_ro
 # Process Row USING NiceCX
 # Added by Aaron G
 #==================================
-def process_row(nice_cx, load_plan, row, node_lookup):
+def process_row(nice_cx_builder, load_plan, row, node_lookup):
     # For each row, we create an edge + edge properties
     # For that edge, we may create elements if they are new
     # - source node + properties
     # - target node + properties
     # - predicate term
 
-    source_node = create_node(row, load_plan.get('source_plan'), nice_cx, node_lookup)
-    target_node = create_node(row, load_plan.get('target_plan'), nice_cx, node_lookup)
+    source_node = create_node(row, load_plan.get('source_plan'), nice_cx_builder, node_lookup)
+    target_node = create_node(row, load_plan.get('target_plan'), nice_cx_builder, node_lookup)
 
-    create_edge(nice_cx, source_node.get_id(), target_node.get_id(), row, load_plan)
+    create_edge(nice_cx_builder, source_node.get_id(), target_node.get_id(), row, load_plan)
 
 def create_node(row, node_plan, nice_cx, node_lookup):
 
@@ -114,10 +120,13 @@ def create_node(row, node_plan, nice_cx, node_lookup):
     use_name_as_id = False
 
     if not node_plan.get('rep_column'):
-        raise Exception("Represents is a required element of the plan")
+        use_name_as_id = True
 
-    if not node_plan.get('node_name_column'):
-        raise Exception("Node name is a required element of the plan")
+#    if not node_plan.get('rep_column'):
+#        raise Exception("Represents is a required element of the plan")
+
+#   if not node_plan.get('node_name_column'):
+#        raise Exception("Node name is a required element of the plan")
 
     if use_name_as_id and node_plan.get('rep_prefix'):
         raise RuntimeError("Id column needs to be defined if id_prefix is defined in your query plan.")
@@ -344,57 +353,59 @@ def add_edge_attributes(nice_cx, edge_id, load_plan, row):
 
 def data_to_type(data, data_type):
     return_data = None
-
-    if(type(data) is str):
-        data = data.replace('[', '').replace(']','')
-        if('list_of' in data_type):
-            data = data.split(',')
-
-    if data_type == "boolean":
+    try:
         if(type(data) is str):
-            return_data = data.lower() == 'true'
+            data = data.replace('[', '').replace(']','')
+            if('list_of' in data_type):
+                data = data.split(',')
+
+        if data_type == "boolean":
+            if(type(data) is str):
+                return_data = data.lower() == 'true'
+            else:
+                return_data = bool(data)
+        elif data_type == "byte":
+            return_data = str(data).encode()
+        elif data_type == "char":
+            return_data = str(data)
+        elif data_type == "double":
+            return_data = float(data)
+        elif data_type == "float":
+            return_data = float(data)
+        elif data_type == "integer":
+            return_data = int(data)
+        elif data_type == "long":
+            return_data = int(data)
+        elif data_type == "short":
+            return_data = int(data)
+        elif data_type == "string":
+            return_data = str(data)
+        elif data_type == "list_of_boolean":
+            # Assumption: if the first element is a string then so are the rest...
+            if(type(data[0]) is str):
+                return_data = [s.lower() == 'true' for s in data]
+            else:
+                return_data = [bool(s) for s in data]
+        elif data_type == "list_of_byte":
+            return_data = [bytes(s) for s in data]
+        elif data_type == "list_of_char":
+            return_data = [str(s) for s in data]
+        elif data_type == "list_of_double":
+            return_data = [float(s) for s in data]
+        elif data_type == "list_of_float":
+            return_data = [float(s) for s in data]
+        elif data_type == "list_of_integer":
+            return_data = [int(s) for s in data]
+        elif data_type == "list_of_long":
+            return_data = [int(s) for s in data]
+        elif data_type == "list_of_short":
+            return_data = [int(s) for s in data]
+        elif data_type == "list_of_string":
+            return_data = [str(s) for s in data]
         else:
-            return_data = bool(data)
-    elif data_type == "byte":
-        return_data = str(data).encode()
-    elif data_type == "char":
-        return_data = str(data)
-    elif data_type == "double":
-        return_data = float(data)
-    elif data_type == "float":
-        return_data = float(data)
-    elif data_type == "integer":
-        return_data = int(data)
-    elif data_type == "long":
-        return_data = int(data)
-    elif data_type == "short":
-        return_data = int(data)
-    elif data_type == "string":
-        return_data = str(data)
-    elif data_type == "list_of_boolean":
-        # Assumption: if the first element is a string then so are the rest...
-        if(type(data[0]) is str):
-            return_data = [s.lower() == 'true' for s in data]
-        else:
-            return_data = [bool(s) for s in data]
-    elif data_type == "list_of_byte":
-        return_data = [bytes(s) for s in data]
-    elif data_type == "list_of_char":
-        return_data = [str(s) for s in data]
-    elif data_type == "list_of_double":
-        return_data = [float(s) for s in data]
-    elif data_type == "list_of_float":
-        return_data = [float(s) for s in data]
-    elif data_type == "list_of_integer":
-        return_data = [int(s) for s in data]
-    elif data_type == "list_of_long":
-        return_data = [int(s) for s in data]
-    elif data_type == "list_of_short":
-        return_data = [int(s) for s in data]
-    elif data_type == "list_of_string":
-        return_data = [str(s) for s in data]
-    else:
-        return_data = str(data)
+            return_data = str(data)
+    except Exception as err2:
+        return_data = None
 
     return return_data
 
@@ -442,7 +453,7 @@ def find_or_create_node(nice_cx, name, represents, node_lookup):
     if node_lookup.get(represents):
         return nice_cx.nodes.get(node_lookup.get(represents))
     else:
-        new_node_id = nice_cx.create_node(node_name=name, node_represents=represents)
+        new_node_id = nice_cx.add_node(name=name, represents=represents) #.create_node(node_name=name, node_represents=represents)
         node_lookup[represents] = new_node_id
         return nice_cx.nodes.get(new_node_id)
 
